@@ -6,9 +6,9 @@ A collection of handy utilities to support django operations.
 :license: GPL-3.0. See LICENSE for more details
 """
 
-__title__ = 'django-handyhelpers'
-__version__ = '0.3.26'
-__author__ = 'David Slusser'
-__email__ = 'dbslusser@gmail.com'
-__license__ = 'GPL-3.0'
-__copyright__ = 'Copyright 2018 David Slusser'
+__title__ = "django-handyhelpers"
+__version__ = "0.3.41"
+__author__ = "David Slusser"
+__email__ = "dbslusser@gmail.com"
+__license__ = "GPL-3.0"
+__copyright__ = "Copyright 2018 David Slusser"
